@@ -4,7 +4,7 @@ import sys
 from pathlib import Path
 
 __package__ = "meld"
-__version__ = "3.22.0"
+__version__ = "3.22.1"
 
 APPLICATION_NAME = 'Meld'
 APPLICATION_ID = 'org.gnome.Meld'
@@ -21,8 +21,8 @@ PROFILE = ''
 
 if CONFIGURED == 'True':
     APPLICATION_ID = 'org.gnome.Meld'
-    DATADIR = '/usr/local/share/meld'
-    LOCALEDIR = '/usr/local/share/locale'
+    DATADIR = '/usr/pkg/share/meld'
+    LOCALEDIR = '/usr/pkg/share/locale'
     PROFILE = ''
 
 # Flag enabling some workarounds if data dir isn't installed in standard prefix
